@@ -800,7 +800,7 @@ class Calibrate(MSONable):
         kpoints
         """
         vis = MPINTVaspInputSet(name, self.incar, self.poscar,
-                                self.potcar, self.kpoints,
+                                self.kpoints, self.potcar,
                                 self.qadapter, vis_logger=self.logger,
                                 reuse_path=self.reuse_paths, test=self.test)
         # the job command can be overrridden in the run method
