@@ -45,16 +45,14 @@ from pymatgen.io.vasp.outputs import Vasprun
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 
 from custodian.custodian import Custodian
+from custodian.vasp.handlers import VaspErrorHandler
 
 from fireworks.user_objects.queue_adapters.common_adapter import CommonAdapter
 
 from ase.build import surface
 
 from mpinterfaces.default_logger import get_default_logger
-from mpinterfaces import set_config, SETTINGS_FILE, PACKAGE_PATH
-
-MPINT_CONFIG, MP_API, VASP_PSP, QUEUE_TEMPLATE, USERNAME,\
- VASP_STD_BIN, VASP_TWOD_BIN, VDW_KERNEL, QUEUE_SYSTEM = set_config()
+from mpinterfaces import *
 
 __author__ = "Kiran Mathew, Joshua J. Gabriel, Michael Ashton"
 __copyright__ = "Copyright 2017, Henniggroup"
@@ -210,7 +208,7 @@ def get_run_cmmnd(nnodes=1, ntasks=16, walltime='10:00:00', job_bin=None,
     """
     d = {}
     job_cmd = None
-    qtemp_file = open(QUEUE_TEMPLATE+'qtemplate.yaml')
+    qtemp_file = open(QUEUE_TEMPLATE+os.sep+'qtemplate.yaml')
     qtemp = yaml.load(qtemp_file)
     qtemp_file.close()
     qtemp.update({'nnodes': nnodes, 'ntasks':ntasks, 'walltime': walltime, \
@@ -1329,15 +1327,18 @@ def load_config_vars(config_dict):
     """
     Loads the given dict of config variables to the environment
     """
-    if os.path.exists(SETTINGS_FILE):
-       f = open(SETTINGS_FILE)
-       current_config = yaml.load(open(SETTINGS_FILE))
-       f.close()
-       current_config.update(config_dict)
-       with open(SETTINGS_FILE,'w') as new_config:
-           yaml.dump(current_config, new_config, default_flow_style=False) 
-    else:
-       warnings.warn('Config file does not seem to exist. Create a ~/.mpint_config.yaml')
+    if not os.path.exists(SETTINGS_FILE):
+       user_configs = {key:None for key in ['username','bulk_binary','twod_binary',\
+               'sol_binary','ncl_binary','custom_binary',\
+               'vdw_kernel','potentials','MAPI_KEY', 'queue_system', 'queue_template']}
+
+       with open(os.path.join(os.path.expanduser('~'),'.mpint_config.yaml'),'w') as config_file:
+          yaml.dump(user_configs, config_file, default_flow_style=False)
+
+    current_config = yaml.load(open(SETTINGS_FILE))
+    current_config.update(config_dict)
+    with open(SETTINGS_FILE,'w') as new_config:
+       yaml.dump(current_config, new_config, default_flow_style=False) 
 
 def write_pbs_runjob(name, nnodes, nprocessors, pmem, walltime, binary):
     """
